==> kubernetes-model-flowcontrol-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/PriorityLevelConfigurationSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PriorityLevelConfigurationSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent<A>{
  public PriorityLevelConfigurationSpecFluentImpl() {
  }
  public PriorityLevelConfigurationSpecFluentImpl(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpec instance) {
    this.withLimited(instance.getLimited()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder limited;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildLimited instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration getLimited() {
    return this.limited!=null?this.limited.build():null;
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration buildLimited() {
    return this.limited!=null?this.limited.build():null;
  }
  public A withLimited(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration limited) {
    _visitables.get("limited").remove(this.limited);
    if (limited!=null){ this.limited= new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder(limited); _visitables.get("limited").add(this.limited);} return (A) this;
  }
  public java.lang.Boolean hasLimited() {
    return this.limited != null;
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<A> withNewLimited() {
    return new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluentImpl.LimitedNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<A> withNewLimitedLike(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration item) {
    return new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluentImpl.LimitedNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<A> editLimited() {
    return withNewLimitedLike(getLimited());
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<A> editOrNewLimited() {
    return withNewLimitedLike(getLimited() != null ? getLimited(): new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<A> editOrNewLimitedLike(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration item) {
    return withNewLimitedLike(getLimited() != null ? getLimited(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PriorityLevelConfigurationSpecFluentImpl that = (PriorityLevelConfigurationSpecFluentImpl) o;
    if (limited != null ? !limited.equals(that.limited) :that.limited != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(limited,  type,  additionalProperties,  super.hashCode());
  }
  public class LimitedNestedImpl<N> extends io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationFluentImpl<io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<N>> implements io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LimitedNestedImpl(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration item) {
      this.builder = new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder(this, item);
    }
    LimitedNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder(this);
    }
    io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder builder;
    public N and() {
      return (N) PriorityLevelConfigurationSpecFluentImpl.this.withLimited(builder.build());
    }
    public N endLimited() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-flowcontrol-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/PriorityLevelConfigurationSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PriorityLevelConfigurationSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent<A>{
  public PriorityLevelConfigurationSpecFluentImpl() {
  }
  public PriorityLevelConfigurationSpecFluentImpl(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpec instance) {
    this.withLimited(instance.getLimited()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder limited;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildLimited instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration getLimited() {
    return this.limited!=null?this.limited.build():null;
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration buildLimited() {
    return this.limited!=null?this.limited.build():null;
  }
  public A withLimited(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration limited) {
    _visitables.get("limited").remove(this.limited);
    if (limited!=null){ this.limited= new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder(limited); _visitables.get("limited").add(this.limited);} return (A) this;
  }
  public java.lang.Boolean hasLimited() {
    return this.limited != null;
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<A> withNewLimited() {
    return new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluentImpl.LimitedNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<A> withNewLimitedLike(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration item) {
    return new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluentImpl.LimitedNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<A> editLimited() {
    return withNewLimitedLike(getLimited());
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<A> editOrNewLimited() {
    return withNewLimitedLike(getLimited() != null ? getLimited(): new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<A> editOrNewLimitedLike(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration item) {
    return withNewLimitedLike(getLimited() != null ? getLimited(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PriorityLevelConfigurationSpecFluentImpl that = (PriorityLevelConfigurationSpecFluentImpl) o;
    if (limited != null ? !limited.equals(that.limited) :that.limited != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(limited,  type,  additionalProperties,  super.hashCode());
  }
  public class LimitedNestedImpl<N> extends io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationFluentImpl<io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<N>> implements io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.PriorityLevelConfigurationSpecFluent.LimitedNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LimitedNestedImpl(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfiguration item) {
      this.builder = new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder(this, item);
    }
    LimitedNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder(this);
    }
    io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.LimitedPriorityLevelConfigurationBuilder builder;
    public N and() {
      return (N) PriorityLevelConfigurationSpecFluentImpl.this.withLimited(builder.build());
    }
    public N endLimited() {
      return and();
    }
    
  }
  
}
